Welcome to `Évariste`'s documentation!
======================================

.. note::

  Évariste is under active development. This is only a draft.

TODO Description

TODO Example

Table of contents
-----------------

.. toctree::
   :numbered:
   :maxdepth: 2

   user/index
   write/index
   lib/index
   tools/index
   external/index

Rationale
---------

TODO

Download and install
--------------------

See the `main project page <http://git.framasoft.org/spalax/evariste>`_ for
instructions, and `changelog
<https://git.framasoft.org/spalax/evariste/blob/master/CHANGELOG.md>`_.

Indices and tables
------------------

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

*Je ne sais pas le reste*
-------------------------

  C'est que malheureusement on ne se doute pas que le livre le plus précieux
  du plus savant serait celui où il dirait tout ce qu'il ne sait pas, c'est
  qu'on ne se doute pas qu'un auteur ne nuit jamais tant à ses lecteurs que
  quand il dissimule une difficulté. Quand la concurrence, c'est-à-dire
  l'égoïsme, ne règnera plus dans la science, quand on s'associera  pour
  étudier, au lieu d'envoyer aux Académies des paquets cachetés, on
  s'empressera de publier ses moindres observations pour peu qu'elles soient
  nouvelles et on ajoutera : « Je ne sais pas le reste. »

  -- Évariste Galois, Préface aux « Deux mémoires d'Analyse pure », décembre 1831
